.TH ilud G "March 2000" "Scilab Group" "Scilab Function"
.so ../sci.an
.SH NAME
ilud - sparse incomplete lu factorization with single dropping and diagonal compensation
.SH CALLING SEQUENCE
.nf
[L,U,ierr]=ilud(A,alph,tol)
.fi
.SH PARAMETERS
.TP
A
: sparse matrix (must be square)
.TP
alph
: diagonal compensation parameter; \fValph\fR uses the default 0.5
.TP
tol
: threshold parameter for dropping small terms in the factorization; \fVtol\fR uses the default 0.001*max(Aij)
.TP
L
: lower triangular matrix
.TP
U
: upper triangular matrix
.TP
ierr
: error message
.SH DESCRIPTION
\fV[L,U,ierr]=ilud(A,alph,tol)\fR builds an incomplete LU factorization of the sparse matrix \fVA\fR. The two factors L and U are stored in the CSR format. The CSR format is the Compressed Sparse Row format used by Scilab.
.LP
All diagonal elements of the input matrix must be nonzero.
.TP 
alph
: The term \fValph\fR*(sum of all dropped out elements in a given row) is added to the diagonal element of U of the factorization. Thus:
.LP
   0  --> ILU with threshold,
.LP
   1  --> MILU with threshold.
.TP
tol
: During the elimination, a term a(i,j) is dropped whenever abs(a(i,j)) .lt. \fVtol\fR * [weighted norm of row i]. Here weighted norm = 1-norm / number of nnz elements in the row.
.TP
ierr
: Error message with the following meaning.
.LP
   0  --> successful return.
.LP
  >0  --> zero pivot encountered at step number ierr.
.LP
  -1  --> Error. input matrix may be wrong. (The elimination process has generated a row in L or U whose length is .gt.  n.)
.LP
  -2  --> Insufficient storage for the LU factors -- arrays alu/jalu are overflowed.
.LP
  -3  --> Zero row encountered.
.SH EXAMPLE
.nf
A=mmread(SCILIN+'/demos/matrices/nos3.mtx')
n=size(A,1); b=ones(n,1);
alph=0;tol=0;
[L,U]=ilud(A,alph,tol);
x=U\(L\b)
A*x-b
.fi
.SH AUTHOR
Aladin Group & Yousef Saad
.SH SEE ALSO
iludp, ilut, milu0, sparse