.TH bicg G "March 2000" "Scilab Group" "Scilab Function"
.so ../sci.an
.SH NAME
bicg - biconjugate gradient method with preconditioning.
.SH CALLING SEQUENCE
.nf
[x,err,iter,flag,res] = bicg(A,Ap,b,x0,M,Mp,maxi,tol)
.fi
.SH PARAMETERS
.TP
A
: matrix of size n-by-n or function returning A*x
.TP
Ap
: exists if \fVA\fR is a function. In this case \fVAp\fR is the transposed function of A, i.e returns A'*x
.TP
b
: right hand side vector
.TP
x0
: initial guess vector; \fVx0\fR uses the default, \fVzeros(n,1)\fR
.TP
M
: preconditioner matrix or function returning M*x; In the first case \fVM\fR uses the default, eye(n,n)
.TP
Mp
: exists if \fVM\fR is a function. In this case \fVMp\fR is the transposed function of M, i.e returns M'*x
.TP
maxi
: maximum number of iterations; \fVmaxi\fR uses the default, n
.TP
tol
: error tolerance; \fVtol\fR uses the default, 1000*%eps
.TP
x
: solution vector
.TP
err
: final residual norm
.TP
iter
: number of iterations performed
.TP
flag
: 0 = solution found to tolerance
.LP
   1 = no convergence given maxi
.LP
  -1 = breakdown
.TP
res
: residual vector
.SH DESCRIPTION
\fV[x,err,iter,flag,res] = bicg(A,Ap,b,x0,M,Mp,maxi,tol)\fR solves the linear system Ax=b using the BiConjugate Gradient Method with preconditioning.
.LP
.SH EXAMPLE
.nf
A=makefish(4); b=rand(16,1);x0=zeros(16,1);
[x,err,iter,flag,res] = bicg(A,b,x0)
M=eye(16,16); max_it=16; tol=1000*%eps;
[x,err,iter,flag,res] = bicg(A,b,x0,M,max_it,tol)

deff("y=precond(x)","y=(M+eye(size(M,1),size(M,2)))*x");
deff("y=precondp(x)","y=(M+eye(size(M,1),size(M,2)))''*x");

deff("y=matvec(x)","y=(A+eye(size(A,1),size(A,1)))*x");
deff("y=matvecp(x)","y=(A+eye(size(A,1),size(A,1)))''*x");

[x,err,iter,flag,res] = bicg(matvec,matvecp,b,x0,precond,precondp,max_it,tol)

[x,err,iter,flag,res] = bicg(matvec,matvecp,b,x0,M,max_it,tol)
[x,err,iter,flag,res] = bicg(A,b,x0,precond,precondp,max_it,tol)

.fi
.SH AUTHOR
Source given by the Univ. of Tennessee and Oak Ridge National Laboratory. Adaptations for Scilab done by Aladin team - 20 March 2001.
.SH SEE ALSO
