.TH bicgstab G "March 2000" "Scilab Group" "Scilab Function"
.so ../sci.an
.SH NAME
bicgstab - biconjugate gradient stabilized method with preconditioning
.SH CALLING SEQUENCE
.nf
[x,err,iter,flag,res] = bicgstab(A,b,x0,M,maxi,tol)
.fi
.SH PARAMETERS
.TP
A
: matrix of size n-by-n or function returning A*x
.TP
b
: right hand side vector
.TP
x0
: initial guess vector; \fVx0\fR uses the default, zeros(n,1)
.TP
M
: preconditioner matrix or function returning M*x; In the first case \fVM\fR uses the default, eye(n,n)
.TP
maxi
: maximum number of iterations; \fVmaxi\fR uses the default, n
.TP
tol
: error tolerance; \fVtol\fR uses the default, 1000*%eps
.TP
x
: solution vector
.TP
err
: final residual norm
.TP
iter
: number of iterations performed
.TP
flag
: 0 = solution found to tolerance
.LP
  1 = no convergence given maxi
.LP
 -1 = breakdown: rho = 0
.LP
 -2 = breakdown: omega = 0
.TP
res
: residual vector
.SH DESCRIPTION
\fV[x,err,iter,flag,res] = bicgstab(A,b,x0,M,maxi,tol)\fR solves the linear system Ax=b using the BiConjugate Gradient Stabilized Method with preconditioning.
.SH EXAMPLE
.nf
A=makefish(4); b=rand(16,1);x0=zeros(16,1);
[x,err,iter,flag,res] = bicgstab(A,b,x0)
M=eye(16,16); max_it=16; tol=1000*%eps;
[x,err,iter,flag,res] = bicgstab(A,b,x0,M,max_it,tol)

deff("y=precond(x)","y=(M+eye(size(M,1),size(M,2)))*x");
deff("y=matvec(x)","y=(A+eye(size(A,1),size(A,1)))*x");

[x,err,iter,flag,res] = bicgstab(matvec,b,x0,precond,max_it,tol)

[x,err,iter,flag,res] = bicgstab(A,b,x0,precond)
[x,err,iter,flag,res] = bicgstab(matvec,b,x0,M)

.fi
.SH AUTHOR
Source given by the Univ. of Tennessee and Oak Ridge National Laboratory. Adaptations for Scilab done by Aladin team - 20 March 2001.
.SH SEE ALSO
