.TH gmres G "March 2000" "Scilab Group" "Scilab Function"
.so ../sci.an
.SH NAME
gmres - generalized minimum residual method with restarts
.SH CALLING SEQUENCE
.nf
[x,err,iter,flag,res] = gmres(A,b,x0,M,rstr,maxi,tol)
.fi
.SH PARAMETERS
.TP
A
: nonsymmetric positive definite matrix of size n-by-n or function returning A*x
.TP
b
: right hand side vector
.TP
x0
: initial guess vector; \fVx0\fR uses the default, zeros(n,1)
.TP
M
: preconditioner matrix or function returning M*x; In the first case \fVM\fR uses the default, eye(n,n)
.TP
rstr
: number of iterations between restarts; \fVrstr\fR uses the default, 10
.TP
maxi
: maximum number of iterations; \fVmaxi\fR uses the default, n
.TP
tol
: error tolerance; \fVtol\fR uses the default, 1000*%eps
.TP
x
: solution vector
.TP
err
: final residual norm
.TP
iter
: number of iterations performed
.TP
flag
: 0 = solution found to tolerance
.LP
  1 = no convergence given maxi
.TP
res
: residual vector
.SH DESCRIPTION
\fV[x,err,iter,flag,res] = gmres(A,b,x0,M,rstr,maxi,tol)\fR solves the linear system \fVAx=b\fR using the Generalized Minimal residual ( GMRESm ) method with restarts.
.LP
The matrix A must be a nonsymmetric positive definite matrix.
.SH EXAMPLE
.nf
A=mmread(SCILIN+'/demos/matrices/pde225.mtx');
n=siz(A,1);b=ones(n,1);x0=zeros(n,1);
[x,err,iter,flag,res] = gmres(A,b,x0)
M=eye(n,n); max_it=n; tol=1000*%eps;rstr=20;
[x,err,iter,flag,res] = gmres(A,b,x0,M,rstr,max_it,tol)

deff("y=precond(x)","y=(M+eye(size(M,1),size(M,2)))*x");
deff("y=matvec(x)","y=(A+eye(size(A,1),size(A,1)))*x");

[x,err,iter,flag,res] = gmres(matvec,b,x0,precond,rstr,max_it,tol)

[x,err,iter,flag,res] = gmres(A,b,x0,precond)
[x,err,iter,flag,res] = gmres(matvec,b,x0,M)
.fi
.SH AUTHOR
Source given by the Univ. of Tennessee and Oak Ridge National Laboratory. Adaptations for Scilab done by Aladin team - 20 March 2001.
.SH SEE ALSO
