.TH qmr G "March 2000" "Scilab Group" "Scilab Function"
.so ../sci.an
.SH NAME
qmr - quasi minimal resiqual method with preconditioning
.SH CALLING SEQUENCE
.nf
[x,err,iter,flag,res] = qmr(A,b,x0,M1,M1p,M2,M2p,maxi,tol)
.fi
.SH PARAMETERS
.TP
A
: matrix of size n-by-n or function returning A*x
.TP
b
: right hand side vector
.TP
x0
: initial guess vector; \fVx0\fR uses the default, zeros(n,1)
.TP
M1
: left preconditioner matrix or function returning M1*x; In the first case \fVM1\fR uses the default, eye(n,n)
.TP
M1p
: exists if M1 is a function. In this case M1p is the transposed function of M1, i.e returns M1'*x
.TP
M2
: right preconditioner matrix or function returning M2*x; In the first case \fVM2\fR uses the default, eye(n,n)
.TP
M2p
:  exists if M2 is a function. In this case M2p is the transposed function of M2, i.e returns M2'*x
.TP
maxi
: maximum number of iterations; \fVmaxi\fR uses the default, n
.TP
tol
: error tolerance; \fVtol\fR uses the default, 1000*%eps
.TP
x
: solution vector
.TP
err
: final residual norm
.TP
iter
: number of iterations performed
.TP
flag
: 0 = solution found to tolerance
.LP
   1 = no convergence given maxi
.TP
res
: residual vector
.SH DESCRIPTION
\fV[x,err,iter,flag,res] = qmr(A,b,x0,M1,M1p,M2,M2p,maxi,tol)\fR solves the linear system Ax=b using the Quasi Minimal Residual Method with preconditioning.
.SH EXAMPLE
.nf
A=makefish(4); b=rand(16,1);x0=zeros(16,1);
[x,err,iter,flag,res] = qmr(A,b,x0)
M1=eye(16,16); M2=M1; max_it=16; tol=1000*%eps;
[x,err,iter,flag,res] = qmr(A,b,x0,M1,M2,max_it,tol)

deff("y=precond_g(x)","y=(M1+eye(size(M1,1),size(M1,2)))*x");
deff("y=precondp_g(x)","y=(M1+eye(size(M1,1),size(M1,2)))''*x");

deff("y=precond_d(x)","y=(M2+6*eye(size(M2,1),size(M2,2)))*x");
deff("y=precondp_d(x)","y=(M2+eye(size(M2,1),size(M2,2)))''*x");

deff("y=matvec(x)","y=(A+eye(size(A,1),size(A,1)))*x");

[x,err,iter,flag,res] = qmr(A,b,x0,precond_g,precondp_g,M2,max_it,tol)
[x,err,iter,flag,res] = qmr(matvec,b,x0,precond_g,precondp_g,precond_d,precondp_d)
.fi
.SH AUTHOR
Source given by the Univ. of Tennessee and Oak Ridge National Laboratory. Adaptations for Scilab done by Aladin team - 20 March 2001.
.SH SEE ALSO
